/* This file was generated by syncqt. */
#ifndef QT_QTWEBENGINEWIDGETS_VERSION_H
#define QT_QTWEBENGINEWIDGETS_VERSION_H

#define QTWEBENGINEWIDGETS_VERSION_STR "6.12.0"

#define QTWEBENGINEWIDGETS_VERSION 0x0601200

#endif // QT_QTWEBENGINEWIDGETS_VERSION_H
