/* This file was generated by syncqt. */
#ifndef QT_QTWEBENGINEQUICK_VERSION_H
#define QT_QTWEBENGINEQUICK_VERSION_H

#define QTWEBENGINEQUICK_VERSION_STR "6.12.0"

#define QTWEBENGINEQUICK_VERSION 0x0601200

#endif // QT_QTWEBENGINEQUICK_VERSION_H
